RoomConnectionScope class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RoomConnectionScope
Constructors
-
RoomConnectionScope({Key? key, required Future<
RoomConnectionInfo> authorization(), required Widget builder(BuildContext context, RoomClient room), Widget doneBuilder(BuildContext context, Object? error)?, Widget authorizingBuilder(BuildContext context)?, Widget retryingBuilder(BuildContext context, Object? error)?, Widget notFoundBuilder(BuildContext context)?, Widget connectingBuilder(BuildContext context, RoomClient room)?, void onReady(RoomClient room)?, bool enableMessaging = true, dynamic oauthTokenRequestHandler(RoomClient, OAuthTokenRequest)?, dynamic secretRequestHandler(RoomClient, SecretRequest)?, String? client, RoomClient roomClientFactory(RoomConnectionInfo connectionInfo)?}) -
const
Properties
-
final
-
final
- builder → Widget Function(BuildContext context, RoomClient room)
-
final
- client → String?
-
final
- connectingBuilder → Widget Function(BuildContext context, RoomClient room)?
-
final
- doneBuilder → Widget Function(BuildContext context, Object? error)?
-
final
- enableMessaging → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- notFoundBuilder → Widget Function(BuildContext context)?
-
final
- oauthTokenRequestHandler → dynamic Function(RoomClient, OAuthTokenRequest)?
-
final
- onReady → void Function(RoomClient room)?
-
final
- retryingBuilder → Widget Function(BuildContext context, Object? error)?
-
final
- roomClientFactory → RoomClient Function(RoomConnectionInfo connectionInfo)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretRequestHandler → dynamic Function(RoomClient, SecretRequest)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited