ChatToolCallRendererRegistry class

Annotations

Constructors

ChatToolCallRendererRegistry({Map<ChatToolCallRendererKey, ChatToolCallRenderer> renderers = const <ChatToolCallRendererKey, ChatToolCallRenderer>{}})
ChatToolCallRendererRegistry.fromToolkits(Iterable<Toolkit> toolkits, {String? namespace, Map<ChatToolCallRendererKey, ChatToolCallRenderer> renderers = const <ChatToolCallRendererKey, ChatToolCallRenderer>{}})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ChatToolCallSnapshot snapshot) ChatToolCallRenderer?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

empty ChatToolCallRendererRegistry
final