ChatToolCallSnapshot class

Annotations

Constructors

ChatToolCallSnapshot({required ChatToolCallIdentity identity, required String namespace, required String toolkit, required String tool, required ChatToolCallStatus status, Map<String, Object?>? arguments, List<ChatToolCallLogEntry> logs = const <ChatToolCallLogEntry>[], int argumentDeltaBytes = 0, Content? result, String? errorMessage, String? authorName, required DateTime startedAt, required DateTime updatedAt})

Properties

argumentDeltaBytes int
final
arguments Map<String, Object?>?
final
authorName String?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
identity ChatToolCallIdentity
final
isTerminal bool
no setter
logs List<ChatToolCallLogEntry>
final
namespace String
final
result → Content?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
status ChatToolCallStatus
final
tool String
final
toolkit String
final
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited