WidgetContentTool class abstract

Inheritance
  • Object
  • BaseTool
  • ContentTool
  • WidgetContentTool
Implemented types

Constructors

WidgetContentTool({required String name, String? description, String? title, required Map<String, dynamic> inputSchema, ToolContentSpec? inputSpec, ToolContentSpec? outputSpec, Map<String, dynamic>? outputSchema, Map<String, dynamic>? defs, required WidgetToolRender render})

Properties

defs Map<String, dynamic>?
finalinherited
description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inputSchema Map<String, dynamic>
finalinherited
inputSpec → ToolContentSpec?
finalinherited
name String
finalinherited
outputSchema Map<String, dynamic>?
finalinherited
outputSpec → ToolContentSpec?
finalinherited
render WidgetToolRender
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
finalinherited

Methods

execute(ToolContext context, ToolInput input) Future<ToolCallOutput>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited